@@ -50,6 +50,10 @@ describe 'ironic' do
       it_configures 'with SSL disabled'
       it_configures 'with SSL enabled without kombu'
       it_configures 'with SSL enabled with kombu'
+      it_configures 'with amqp_durable_queues disabled'
+      it_configures 'with amqp_durable_queues enabled'
+      it_configures 'with one glance server'
+      it_configures 'with two glance servers'
     end
 
     context 'and if rabbit_hosts parameter is provided' do
@@ -211,7 +215,7 @@ describe 'ironic' do
 
   shared_examples_for 'with amqp_durable_queues enabled' do
     before do
-      params.merge( :amqp_durable_queues => true )
+      params.merge!( :amqp_durable_queues => true )
     end
 
     it { is_expected.to contain_ironic_config('oslo_messaging_rabbit/amqp_durable_queues').with_value(true) }
@@ -223,7 +227,7 @@ describe 'ironic' do
     end
 
     it 'should configure one glance server' do
-      is_expected.to contain_ironic_config('glance/glance_api_servers').with_value(p[:glance_api_servers])
+      is_expected.to contain_ironic_config('glance/glance_api_servers').with_value(params[:glance_api_servers])
     end
   end
 
@@ -233,62 +237,13 @@ describe 'ironic' do
     end
 
     it 'should configure one glance server' do
-       is_expected.to contain_ironic_config('glance/glance_api_servers').with_value(p[:glance_api_servers].join(','))
+       is_expected.to contain_ironic_config('glance/glance_api_servers').with_value(params[:glance_api_servers].join(','))
     end
   end
 
-  shared_examples_for 'with qpid rpc backend' do
-    before do
-      params.merge!({ :rpc_backend => 'qpid' })
-    end
-
-    it { is_expected.to contain_neutron_config('DEFAULT/rpc_backend').with_value('qpid') }
-
-    context 'when default params' do
-      it { is_expected.to contain_neutron_config('oslo_messaging_qpid/qpid_username').with_value('guest') }
-      it { is_expected.to contain_neutron_config('oslo_messaging_qpid/qpid_password').with_value('guest').with_secret(true) }
-      it { is_expected.to contain_neutron_config('oslo_messaging_qpid/qpid_hostname').with_value('localhost') }
-      it { is_expected.to contain_neutron_config('oslo_messaging_qpid/qpid_port').with_value('5672') }
-      it { is_expected.to contain_neutron_config('oslo_messaging_qpid/qpid_protocol').with_value('tcp') }
-      it { is_expected.to contain_neutron_config('oslo_messaging_qpid/qpid_heartbeat').with_value('60') }
-      it { is_expected.to contain_neutron_config('oslo_messaging_qpid/qpid_tcp_nodelay').with_value('true') }
-      it { is_expected.to contain_neutron_config('oslo_messaging_qpid/qpid_reconnect').with_value('true') }
-      it { is_expected.to contain_neutron_config('oslo_messaging_qpid/qpid_reconnect_timeout').with_value('0') }
-      it { is_expected.to contain_neutron_config('oslo_messaging_qpid/qpid_reconnect_limit').with_value('0') }
-      it { is_expected.to contain_neutron_config('oslo_messaging_qpid/qpid_reconnect_interval_min').with_value('0') }
-      it { is_expected.to contain_neutron_config('oslo_messaging_qpid/qpid_reconnect_interval_max').with_value('0') }
-      it { is_expected.to contain_neutron_config('oslo_messaging_qpid/qpid_reconnect_interval').with_value('0') }
-    end
-
-    context 'when passing params' do
-      before do
-        params.merge!({
-          :qpid_password       => 'pass',
-          :qpid_username       => 'guest2',
-          :qpid_hostname       => 'localhost2',
-          :qpid_port           => '5673',
-          :qpid_protocol       => 'udp',
-          :qpid_heartbeat      => '89',
-          :qpid_tcp_nodelay    => 'false',
-          :qpid_reconnect      => 'false',
-        })
-      end
-
-      it { is_expected.to contain_neutron_config('oslo_messaging_qpid/qpid_username').with_value('guest2') }
-      it { is_expected.to contain_neutron_config('oslo_messaging_qpid/qpid_password').with_value('pass').with_secret(true) }
-      it { is_expected.to contain_neutron_config('oslo_messaging_qpid/qpid_hostname').with_value('localhost2') }
-      it { is_expected.to contain_neutron_config('oslo_messaging_qpid/qpid_port').with_value('5673') }
-      it { is_expected.to contain_neutron_config('oslo_messaging_qpid/qpid_protocol').with_value('udp') }
-      it { is_expected.to contain_neutron_config('oslo_messaging_qpid/qpid_heartbeat').with_value('89') }
-      it { is_expected.to contain_neutron_config('oslo_messaging_qpid/qpid_tcp_nodelay').with_value('false') }
-      it { is_expected.to contain_neutron_config('oslo_messaging_qpid/qpid_reconnect').with_value('false') }
-    end
-
-  end
-
   context 'on Debian platforms' do
     let :facts do
-      { :osfamily => 'Debian' }
+      @default_facts.merge({ :osfamily => 'Debian' })
     end
 
     let :platform_params do
@@ -300,7 +255,7 @@ describe 'ironic' do
 
   context 'on RedHat platforms' do
     let :facts do
-      { :osfamily => 'RedHat' }
+      @default_facts.merge({ :osfamily => 'RedHat' })
     end
 
     let :platform_params do
